@@ -4,14 +4,11 @@ use 5.010_000;
 use strict;
 use warnings;
 
-our $VERSION = '0.1011';
+our $VERSION = '0.1012';
 
 use parent qw(Exporter);
 our @EXPORT_OK = qw(escaped_string html_escape);
 
-use XSLoader;
-XSLoader::load(__PACKAGE__, $VERSION);
-
 use Text::Xslate::Util qw(
     $NUMBER $STRING $DEBUG
     literal_to_value
@@ -20,6 +17,17 @@ use Text::Xslate::Util qw(
 
 use constant _DUMP_LOAD_FILE => scalar($DEBUG =~ /\b dump=load_file \b/xms);
 
+if($DEBUG !~ /\b pp \b/xms) {
+    eval {
+        require XSLoader;
+        XSLoader::load(__PACKAGE__, $VERSION);
+    };
+}
+if(!defined &_initialize) {
+    require 'Text/Xslate/PP.pm';
+    Text::Xslate::PP->import();
+}
+
 use File::Spec;
 
 my $IDENT   = qr/(?: [a-zA-Z_][a-zA-Z0-9_\@]* )/xms;
@@ -113,8 +121,6 @@ sub find_file {
         $orig_mtime = (stat($fullpath))[9] // next; # does not exist
 
         $cachepath = File::Spec->catfile($self->{cache_dir}, $file . 'c');
-        # find the cache
-        # TODO
 
         if(-f $cachepath) {
             $cache_mtime = (stat(_))[9]; # compiled
@@ -187,6 +193,18 @@ sub load_file {
     my $protocode;
     if($is_compiled) {
         $protocode = $self->_load_assembly($string);
+
+        # checks the mtime of dependencies
+        foreach my $code(@{$protocode}) {
+            if($code->[0] eq 'depend') {
+                my $dep_mtime = (stat $code->[1])[9];
+                if($dep_mtime > ($mtime // $f->{orig_mtime})){
+                    unlink $cachepath
+                        or $self->_error("LoadError: Cannot unlink $cachepath: $!");
+                    goto &load_file; # retry
+                }
+            }
+        }
     }
     else {
         $protocode = $self->_compiler->compile($string,
@@ -322,7 +340,7 @@ Text::Xslate - High performance template engine
 
 =head1 VERSION
 
-This document describes Text::Xslate version 0.1011.
+This document describes Text::Xslate version 0.1012.
 
 =head1 SYNOPSIS
 
@@ -564,17 +582,11 @@ the value is defined or not:
     : if $value == nil { ; }
     : if $value != nil { ; }
 
-    [% # on TTerse syntax -%]
-    [% IF $value == nil %] [% END %]
-    [% IF $value != nil %] [% END %]
-
 Or, you can also use defined-or operator (//):
 
-    : # on Kolon syntax
     Hello, <: $value // 'Xslate' :> world!
 
-    [% # on TTerse syntax %]
-    Hello, [% $value // 'Xslate' %] world!
+In TTerse, however, you can print nil as an empty string.
 
 =head1 DEPENDENCIES
 
